<?php
/**
 * Template Name: Layout Narrow Template
 * 
 * Template Post Type: Post, Page
 * 
 * Template part for displaying narrow contene layout in single.php and page.php
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 * 
 * @since 2.0.0
 *
 * @package nesiapress
 */

get_header(); ?>

<main id="primary" class="site-main">

	<div class="np-container">
		<?php
		while ( have_posts() ) :
			the_post();

			// get_template_part( 'template-parts/content', get_post_type() );
			get_template_part( 'template-parts/content', 'narrow' );
		?>
	</div>

	<div class="np-navigation">
		<div class="np-container">
			<?php
				the_post_navigation(
					array(
						'prev_text' => '<span class="nav-subtitle">' . esc_html__( 'Previous:', 'nesiapress' ) . '</span> <span class="nav-title">%title</span>',
						'next_text' => '<span class="nav-subtitle">' . esc_html__( 'Next:', 'nesiapress' ) . '</span> <span class="nav-title">%title</span>',
					)
				);
			?>
		</div>
	</div>

	<div class="np-container">
			<div class="text-center">
				<h2 class="text-2xl font-extrabold tracking-tight text-gray-900">Related post</h2>
			</div>
			<?php
				$tags = wp_get_post_terms( get_queried_object_id(), 'post_tag', ['fields' => 'ids'] );
				$args = [
					'post__not_in'        => array( get_queried_object_id() ),
					'posts_per_page'      => 4,
					'ignore_sticky_posts' => 1,
					'orderby'             => 'rand',
					'tax_query' => [
						[
							'taxonomy' => 'post_tag',
							'terms'    => $tags
						]
					]
				];
				$my_query = new wp_query( $args );
					if( $my_query->have_posts() ) {
						echo '<div class="mt-12 mx-auto grid gap-6 md:grid-cols-2 xl:grid-cols-4 lg:max-w-none">';
					while( $my_query->have_posts() ) {
					$my_query->the_post(); ?>
					<!-- .entry-card -->
					<div class="flex flex-col rounded-lg shadow-lg overflow-hidden">
						<!-- .np-entry-thumbnail -->
						<figure class="flex-shrink-0">
							<?php nesiapress_post_thumbnail(); ?>
						</figure>
						<!-- .np-entry-content -->
						<article class="flex-1 bg-white p-6 flex flex-col justify-between">
							<!-- .np-entry-header -->
							<header class="flex-1">
								<!-- .cat-links -->
								<?php nesiapress_cat_links();?>
								<!-- .entry-title -->
								<h2 class="np-related-title">
									<a href="<?php the_permalink()?>" rel="bookmark" title="<?php the_title(); ?>" rel="nofollow"><?php the_title(); ?></a>
								</h2>
							</header>
							<!-- .np-entry-meta -->
							<footer class="mt-6 flex items-center">
								<!-- .meta-gravatar -->
								<div class="meta-gravatar">
									<span class="sr-only"><?php the_author(); ?></span>
									<?php echo get_avatar( get_the_author_meta( 'ID' ), 40 ); ?>
								</div>
								<div class="np-entry-info">
									<!-- .meta-author -->
									<?php nesiapress_meta_author(); ?>
									
									<div class="meta-info">
										<?php nesiapress_post_update(); ?>
									</div> <!-- .meta-info -->
								</div> <!-- .np-entry-info -->
							</footer>
						</article>
					</div>
				<?php }
				wp_reset_postdata();
					echo '</div>';
				}
			?>
		</div>

	<div class="np-container">
	<?php
		// If comments are open or we have at least one comment, load up the comment template.
		if ( comments_open() || get_comments_number() ) :
			comments_template();
		endif;

		endwhile; // End of the loop.
	?>
	</div>

</main><!-- #main -->

<?php get_footer();