<?php
/**
 * Template Name: Layout Sidebar Right Template
 * 
 * Template Post Type: Post, Page
 * 
 * Template part for displaying narrow contene layout in single.php and page.php
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 * 
 * @since 2.0.0
 *
 * @package nesiapress
 */

get_header(); ?>

<main id="primary" class="site-main">

	<div class="np-container">
		<div class="np-layout-entries">
			<section class="np-layout-content-right">
				<?php
				while ( have_posts() ) :
					the_post();

					get_template_part( 'template-parts/content', 'sidebar-right' );

					the_post_navigation(
						array(
							'prev_text' => '<span class="nav-subtitle">' . esc_html__( 'Previous:', 'nesiapress' ) . '</span> <span class="nav-title">%title</span>',
							'next_text' => '<span class="nav-subtitle">' . esc_html__( 'Next:', 'nesiapress' ) . '</span> <span class="nav-title">%title</span>',
						)
					);

					$tags = wp_get_post_terms( get_queried_object_id(), 'post_tag', ['fields' => 'ids'] );
					$args = [
						'post__not_in'        => array( get_queried_object_id() ),
						'posts_per_page'      => 4,
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
						'tax_query' => [
							[
								'taxonomy' => 'post_tag',
								'terms'    => $tags
							]
						]
					];
					$my_query = new wp_query( $args );
						if( $my_query->have_posts() ) {
							echo '<div class="mt-12 mx-auto grid gap-6 md:grid-cols-2 lg:max-w-none">';
						while( $my_query->have_posts() ) {
						$my_query->the_post(); ?>
						<!-- .entry-card -->
						<div class="flex flex-col rounded-lg shadow-lg overflow-hidden">
							<!-- .np-entry-thumbnail -->
							<figure class="flex-shrink-0">
								<?php nesiapress_post_thumbnail(); ?>
							</figure>
							<!-- .np-entry-content -->
							<article class="flex-1 bg-white p-6 flex flex-col justify-between">
								<!-- .np-entry-header -->
								<header class="flex-1">
									<!-- .cat-links -->
									<?php nesiapress_cat_links();?>
									<!-- .entry-title -->
									<h2 class="np-related-title">
										<a href="<?php the_permalink()?>" rel="bookmark" title="<?php the_title(); ?>" rel="nofollow"><?php the_title(); ?></a>
									</h2>
								</header>
								<!-- .np-entry-meta -->
								<footer class="mt-6 flex items-center">
									<!-- .meta-gravatar -->
									<div class="meta-gravatar">
										<span class="sr-only"><?php the_author(); ?></span>
										<?php echo get_avatar( get_the_author_meta( 'ID' ), 40 ); ?>
									</div>
									<div class="np-entry-info">
										<!-- .meta-author -->
										<?php nesiapress_meta_author(); ?>

										<div class="meta-info">
											<?php nesiapress_post_update(); ?>
										</div> <!-- .meta-info -->
									</div> <!-- .np-entry-info -->
								</footer>
							</article>
						</div>
					<?php }
					wp_reset_postdata();
						echo '</div>';
					}

					// If comments are open or we have at least one comment, load up the comment template.
					if ( comments_open() || get_comments_number() ) :
						comments_template();
					endif;

				endwhile; // End of the loop.
				?>
			</section>
			<div id="secondary" aria-labelledby="secondary" class="np-layout-aside-right">
				<?php get_sidebar(); ?>
			</div><!-- #secondary -->
		</div>
	</div>

</main><!-- #main -->

<?php get_footer();